@@ -9,22 +9,27 @@ from indico.errors import IndicoInvalidConfigSetting
 class IndicoConfig:
     """
     Configuration for the IndicoClient.
-    
+
     Args:
         host= (str, optional): Indico Platform hostname (ie indico.myco.com)
         api_token_path= (str, optional): Path to the Indico API token file indico_api_token.txt
-    
+        api_token= (str, optional): The actual text of the API Token
+        verify_ssl= (bool, optional): Verify the host's SSL certificate? Default=True
+
     Returns:
         IndicoConfig object
-    
+
     Raises:
         RuntimeError: If api_token_path does not exist.
-    
+
     Notes:
-        By default, the IndicoConfig constructor will set host and api_token_path from the 
+        By default, the IndicoConfig constructor will set host and api_token_path from the
         INDICO_HOST and INDICO_API_TOKEN_PATH environment variables. If these variable are
         not set then it will use ``app.indico.io`` as the host and will look for the
         indico_api_token.txt file in the user's home directory.
+
+        If your Indico Platform host is configured to use http instead of https or if the
+        host has an invalid SSL certificate then be sure to set verify_ssl=True
     """
 
     host: str
@@ -52,8 +57,6 @@ class IndicoConfig:
 
     def _resolve_api_token(self):
         path = self.api_token_path
-        if path is None:
-            path = "."
         if not isinstance(path, Path):
             path = Path(path)
         if not path.exists():
@@ -63,8 +66,8 @@ class IndicoConfig:
 
         if not path.exists():
             raise RuntimeError(
-                "Expected indico_api_token.txt in current directory, home directory, "
-                "or provided as indicoio.config.token_path"
+                "Expected indico_api_token.txt in home directory, "
+                "or provided as indicoio.config.api_token_path"
             )
 
         with path.open("r") as f:
