@@ -16,9 +16,11 @@ class ModelGroup(BaseType):
         name (str): The name of the model group
         status (str): "CREATED", "TRAINING", "COMPLETE" or "FAILED"
         selected model (Model): A Model object representing the selected (active) model.
+        task_type (str): Type of machine learning task the model solves
     """
 
     id: int
     name: str
     status: str
     selected_model: Model
+    task_type: str
